You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2019/05/30 19:11:00 UTC

[commons-net] branch master updated: Javadoc: Use "file name" instead of "filename". Camel case vars "filename" to "fileName".

This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-net.git


The following commit(s) were added to refs/heads/master by this push:
     new 125ad9b  Javadoc: Use "file name" instead of "filename". Camel case vars "filename" to "fileName".
125ad9b is described below

commit 125ad9bbf4876ec4676c01929218550acb13cc20
Author: Gary Gregory <ga...@gmail.com>
AuthorDate: Thu May 30 15:10:54 2019 -0400

    Javadoc: Use "file name" instead of "filename". Camel case vars
    "filename" to "fileName".
---
 .../apache/commons/net/examples/mail/SMTPMail.java |  2 +-
 .../commons/net/examples/nntp/PostMessage.java     |  2 +-
 src/main/java/org/apache/commons/net/ftp/FTP.java  |  2 +-
 .../java/org/apache/commons/net/ftp/FTPClient.java | 54 ++++++++++-----------
 .../net/ftp/parser/OS400FTPEntryParser.java        |  2 +-
 .../ftp/parser/VMSVersioningFTPEntryParser.java    |  2 +-
 .../org/apache/commons/net/tftp/TFTPClient.java    | 56 +++++++++++-----------
 .../commons/net/tftp/TFTPReadRequestPacket.java    |  8 ++--
 .../apache/commons/net/tftp/TFTPRequestPacket.java | 14 +++---
 .../commons/net/tftp/TFTPWriteRequestPacket.java   |  8 ++--
 10 files changed, 75 insertions(+), 75 deletions(-)

diff --git a/src/main/java/org/apache/commons/net/examples/mail/SMTPMail.java b/src/main/java/org/apache/commons/net/examples/mail/SMTPMail.java
index ccbfb06..e3a6eb2 100644
--- a/src/main/java/org/apache/commons/net/examples/mail/SMTPMail.java
+++ b/src/main/java/org/apache/commons/net/examples/mail/SMTPMail.java
@@ -36,7 +36,7 @@ import org.apache.commons.net.smtp.SimpleSMTPHeader;
 /***
  * This is an example program using the SMTP package to send a message
  * to the specified recipients.  It prompts you for header information and
- * a filename containing the message.
+ * a file name containing the message.
  ***/
 
 public final class SMTPMail
diff --git a/src/main/java/org/apache/commons/net/examples/nntp/PostMessage.java b/src/main/java/org/apache/commons/net/examples/nntp/PostMessage.java
index 7a23ce1..043260c 100644
--- a/src/main/java/org/apache/commons/net/examples/nntp/PostMessage.java
+++ b/src/main/java/org/apache/commons/net/examples/nntp/PostMessage.java
@@ -35,7 +35,7 @@ import org.apache.commons.net.nntp.SimpleNNTPHeader;
 /***
  * This is an example program using the NNTP package to post an article
  * to the specified newsgroup(s).  It prompts you for header information and
- * a filename to post.
+ * a file name to post.
  ***/
 
 public final class PostMessage
diff --git a/src/main/java/org/apache/commons/net/ftp/FTP.java b/src/main/java/org/apache/commons/net/ftp/FTP.java
index bbb7c25..bc62e15 100644
--- a/src/main/java/org/apache/commons/net/ftp/FTP.java
+++ b/src/main/java/org/apache/commons/net/ftp/FTP.java
@@ -446,7 +446,7 @@ public class FTP extends SocketClient
     /**
      * Saves the character encoding to be used by the FTP control connection.
      * Some FTP servers require that commands be issued in a non-ASCII
-     * encoding like UTF-8 so that filenames with multi-byte character
+     * encoding like UTF-8 so that file names with multi-byte character
      * representations (e.g, Big 8) can be specified.
      * <p>
      * Please note that this has to be set before the connection is established.
diff --git a/src/main/java/org/apache/commons/net/ftp/parser/OS400FTPEntryParser.java b/src/main/java/org/apache/commons/net/ftp/parser/OS400FTPEntryParser.java
index bdab2c7..c45b617 100644
--- a/src/main/java/org/apache/commons/net/ftp/parser/OS400FTPEntryParser.java
+++ b/src/main/java/org/apache/commons/net/ftp/parser/OS400FTPEntryParser.java
@@ -243,7 +243,7 @@ public class OS400FTPEntryParser extends ConfigurableFTPFileEntryParserImpl
         + "(?:(\\d+)\\s+)?"           // size, empty for members
         + "(?:(\\S+)\\s+(\\S+)\\s+)?" // date stuff, empty for members
         + "(\\*STMF|\\*DIR|\\*FILE|\\*MEM)\\s+"  // *STMF/*DIR/*FILE/*MEM
-        + "(?:(\\S+)\\s*)?";          // filename, missing, when CWD is a *FILE
+        + "(?:(\\S+)\\s*)?";          // file name, missing, when CWD is a *FILE
 
 
     /**
diff --git a/src/main/java/org/apache/commons/net/ftp/parser/VMSVersioningFTPEntryParser.java b/src/main/java/org/apache/commons/net/ftp/parser/VMSVersioningFTPEntryParser.java
index fd28345..ad445fd 100644
--- a/src/main/java/org/apache/commons/net/ftp/parser/VMSVersioningFTPEntryParser.java
+++ b/src/main/java/org/apache/commons/net/ftp/parser/VMSVersioningFTPEntryParser.java
@@ -30,7 +30,7 @@ import org.apache.commons.net.ftp.FTPClientConfig;
 /**
  * Special implementation VMSFTPEntryParser with versioning turned on.
  * This parser removes all duplicates and only leaves the version with the highest
- * version number for each filename.
+ * version number for each file name.
  *
  * This is a sample of VMS LIST output
  *
diff --git a/src/main/java/org/apache/commons/net/tftp/TFTPClient.java b/src/main/java/org/apache/commons/net/tftp/TFTPClient.java
index 3ea5541..8515ce8 100644
--- a/src/main/java/org/apache/commons/net/tftp/TFTPClient.java
+++ b/src/main/java/org/apache/commons/net/tftp/TFTPClient.java
@@ -134,7 +134,7 @@ public class TFTPClient extends TFTP
      * invoking this method.  This method will not close the OutputStream
      * containing the file; you must close it after the method invocation.
      *
-     * @param filename  The name of the file to receive.
+     * @param fileName  The name of the file to receive.
      * @param mode   The TFTP mode of the transfer (one of the MODE constants).
      * @param output The OutputStream to which the file should be written.
      * @param host   The remote host serving the file.
@@ -143,7 +143,7 @@ public class TFTPClient extends TFTP
      * @throws IOException If an I/O error occurs.  The nature of the
      *            error will be reported in the message.
      ***/
-    public int receiveFile(String filename, int mode, OutputStream output,
+    public int receiveFile(String fileName, int mode, OutputStream output,
                            InetAddress host, int port) throws IOException
     {
         int bytesRead = 0;
@@ -158,7 +158,7 @@ public class TFTPClient extends TFTP
             output = new FromNetASCIIOutputStream(output);
         }
 
-        TFTPPacket sent = new TFTPReadRequestPacket(host, port, filename, mode);
+        TFTPPacket sent = new TFTPReadRequestPacket(host, port, fileName, mode);
         TFTPAckPacket ack = new TFTPAckPacket(host, port, 0);
 
         beginBufferedOps();
@@ -275,7 +275,7 @@ public class TFTPClient extends TFTP
      * invoking this method.  This method will not close the OutputStream
      * containing the file; you must close it after the method invocation.
      *
-     * @param filename The name of the file to receive.
+     * @param fileName The name of the file to receive.
      * @param mode     The TFTP mode of the transfer (one of the MODE constants).
      * @param output   The OutputStream to which the file should be written.
      * @param hostname The name of the remote host serving the file.
@@ -285,19 +285,19 @@ public class TFTPClient extends TFTP
      *            error will be reported in the message.
      * @throws UnknownHostException  If the hostname cannot be resolved.
      ***/
-    public int receiveFile(String filename, int mode, OutputStream output,
+    public int receiveFile(String fileName, int mode, OutputStream output,
                            String hostname, int port)
     throws UnknownHostException, IOException
     {
-        return receiveFile(filename, mode, output, InetAddress.getByName(hostname),
+        return receiveFile(fileName, mode, output, InetAddress.getByName(hostname),
                            port);
     }
 
 
     /***
-     * Same as calling receiveFile(filename, mode, output, host, TFTP.DEFAULT_PORT).
+     * Same as calling receiveFile(fileName, mode, output, host, TFTP.DEFAULT_PORT).
      *
-     * @param filename The name of the file to receive.
+     * @param fileName The name of the file to receive.
      * @param mode     The TFTP mode of the transfer (one of the MODE constants).
      * @param output   The OutputStream to which the file should be written.
      * @param host     The remote host serving the file.
@@ -305,17 +305,17 @@ public class TFTPClient extends TFTP
      * @throws IOException If an I/O error occurs.  The nature of the
      *            error will be reported in the message.
      ***/
-    public int receiveFile(String filename, int mode, OutputStream output,
+    public int receiveFile(String fileName, int mode, OutputStream output,
                            InetAddress host)
     throws IOException
     {
-        return receiveFile(filename, mode, output, host, DEFAULT_PORT);
+        return receiveFile(fileName, mode, output, host, DEFAULT_PORT);
     }
 
     /***
-     * Same as calling receiveFile(filename, mode, output, hostname, TFTP.DEFAULT_PORT).
+     * Same as calling receiveFile(fileName, mode, output, hostname, TFTP.DEFAULT_PORT).
      *
-     * @param filename The name of the file to receive.
+     * @param fileName The name of the file to receive.
      * @param mode     The TFTP mode of the transfer (one of the MODE constants).
      * @param output   The OutputStream to which the file should be written.
      * @param hostname The name of the remote host serving the file.
@@ -324,11 +324,11 @@ public class TFTPClient extends TFTP
      *            error will be reported in the message.
      * @throws UnknownHostException  If the hostname cannot be resolved.
      ***/
-    public int receiveFile(String filename, int mode, OutputStream output,
+    public int receiveFile(String fileName, int mode, OutputStream output,
                            String hostname)
     throws UnknownHostException, IOException
     {
-        return receiveFile(filename, mode, output, InetAddress.getByName(hostname),
+        return receiveFile(fileName, mode, output, InetAddress.getByName(hostname),
                            DEFAULT_PORT);
     }
 
@@ -341,7 +341,7 @@ public class TFTPClient extends TFTP
      * invoking this method.  This method will not close the InputStream
      * containing the file; you must close it after the method invocation.
      *
-     * @param filename The name the remote server should use when creating
+     * @param fileName The name the remote server should use when creating
      *        the file on its file system.
      * @param mode     The TFTP mode of the transfer (one of the MODE constants).
      * @param input the input stream containing the data to be sent
@@ -350,7 +350,7 @@ public class TFTPClient extends TFTP
      * @throws IOException If an I/O error occurs.  The nature of the
      *            error will be reported in the message.
      ***/
-    public void sendFile(String filename, int mode, InputStream input,
+    public void sendFile(String fileName, int mode, InputStream input,
                          InetAddress host, int port) throws IOException
     {
         int block = 0;
@@ -364,7 +364,7 @@ public class TFTPClient extends TFTP
             input = new ToNetASCIIInputStream(input);
         }
 
-        TFTPPacket sent = new TFTPWriteRequestPacket(host, port, filename, mode);
+        TFTPPacket sent = new TFTPWriteRequestPacket(host, port, fileName, mode);
         TFTPDataPacket data = new TFTPDataPacket(host, port, 0, _sendBuffer, 4, 0);
 
         beginBufferedOps();
@@ -485,7 +485,7 @@ public class TFTPClient extends TFTP
      * invoking this method.  This method will not close the InputStream
      * containing the file; you must close it after the method invocation.
      *
-     * @param filename The name the remote server should use when creating
+     * @param fileName The name the remote server should use when creating
      *        the file on its file system.
      * @param mode     The TFTP mode of the transfer (one of the MODE constants).
      * @param input the input stream containing the data to be sent
@@ -495,18 +495,18 @@ public class TFTPClient extends TFTP
      *            error will be reported in the message.
      * @throws UnknownHostException  If the hostname cannot be resolved.
      ***/
-    public void sendFile(String filename, int mode, InputStream input,
+    public void sendFile(String fileName, int mode, InputStream input,
                          String hostname, int port)
     throws UnknownHostException, IOException
     {
-        sendFile(filename, mode, input, InetAddress.getByName(hostname), port);
+        sendFile(fileName, mode, input, InetAddress.getByName(hostname), port);
     }
 
 
     /***
-     * Same as calling sendFile(filename, mode, input, host, TFTP.DEFAULT_PORT).
+     * Same as calling sendFile(fileName, mode, input, host, TFTP.DEFAULT_PORT).
      *
-     * @param filename The name the remote server should use when creating
+     * @param fileName The name the remote server should use when creating
      *        the file on its file system.
      * @param mode     The TFTP mode of the transfer (one of the MODE constants).
      * @param input the input stream containing the data to be sent
@@ -515,17 +515,17 @@ public class TFTPClient extends TFTP
      *            error will be reported in the message.
      * @throws UnknownHostException  If the hostname cannot be resolved.
      ***/
-    public void sendFile(String filename, int mode, InputStream input,
+    public void sendFile(String fileName, int mode, InputStream input,
                          InetAddress host)
     throws IOException
     {
-        sendFile(filename, mode, input, host, DEFAULT_PORT);
+        sendFile(fileName, mode, input, host, DEFAULT_PORT);
     }
 
     /***
-     * Same as calling sendFile(filename, mode, input, hostname, TFTP.DEFAULT_PORT).
+     * Same as calling sendFile(fileName, mode, input, hostname, TFTP.DEFAULT_PORT).
      *
-     * @param filename The name the remote server should use when creating
+     * @param fileName The name the remote server should use when creating
      *        the file on its file system.
      * @param mode     The TFTP mode of the transfer (one of the MODE constants).
      * @param input the input stream containing the data to be sent
@@ -534,11 +534,11 @@ public class TFTPClient extends TFTP
      *            error will be reported in the message.
      * @throws UnknownHostException  If the hostname cannot be resolved.
      ***/
-    public void sendFile(String filename, int mode, InputStream input,
+    public void sendFile(String fileName, int mode, InputStream input,
                          String hostname)
     throws UnknownHostException, IOException
     {
-        sendFile(filename, mode, input, InetAddress.getByName(hostname),
+        sendFile(fileName, mode, input, InetAddress.getByName(hostname),
                  DEFAULT_PORT);
     }
 }
diff --git a/src/main/java/org/apache/commons/net/ftp/FTPClient.java b/src/main/java/org/apache/commons/net/ftp/FTPClient.java
index 704dc32..94cd7ff 100644
--- a/src/main/java/org/apache/commons/net/ftp/FTPClient.java
+++ b/src/main/java/org/apache/commons/net/ftp/FTPClient.java
@@ -1678,7 +1678,7 @@ implements Configurable
      * server to which the client is connected to retrieve a given file from
      * the other server.
      *
-     * @param filename  The name of the file to retrieve.
+     * @param fileName  The name of the file to retrieve.
      * @return True if successfully completed, false if not.
      * @throws FTPConnectionClosedException
      *      If the FTP server prematurely closes the connection as a result
@@ -1688,11 +1688,11 @@ implements Configurable
      * @throws IOException  If an I/O error occurs while either sending a
      *      command to the server or receiving a reply from the server.
      */
-    public boolean remoteRetrieve(String filename) throws IOException
+    public boolean remoteRetrieve(String fileName) throws IOException
     {
         if (__dataConnectionMode == ACTIVE_REMOTE_DATA_CONNECTION_MODE ||
                 __dataConnectionMode == PASSIVE_REMOTE_DATA_CONNECTION_MODE) {
-            return FTPReply.isPositivePreliminary(retr(filename));
+            return FTPReply.isPositivePreliminary(retr(fileName));
         }
         return false;
     }
@@ -1701,11 +1701,11 @@ implements Configurable
     /**
      * Initiate a server to server file transfer.  This method tells the
      * server to which the client is connected to store a file on
      * the other server using the given filename.  The other server must
      * have had a <code> remoteRetrieve </code> issued to it by another
      * FTPClient.
      *
-     * @param filename  The name to call the file that is to be stored.
+     * @param fileName  The name to call the file that is to be stored.
      * @return True if successfully completed, false if not.
      * @throws FTPConnectionClosedException
      *      If the FTP server prematurely closes the connection as a result
@@ -1715,11 +1715,11 @@ implements Configurable
      * @throws IOException  If an I/O error occurs while either sending a
      *      command to the server or receiving a reply from the server.
      */
-    public boolean remoteStore(String filename) throws IOException
+    public boolean remoteStore(String fileName) throws IOException
     {
         if (__dataConnectionMode == ACTIVE_REMOTE_DATA_CONNECTION_MODE ||
                 __dataConnectionMode == PASSIVE_REMOTE_DATA_CONNECTION_MODE) {
-            return FTPReply.isPositivePreliminary(stor(filename));
+            return FTPReply.isPositivePreliminary(stor(fileName));
         }
         return false;
     }
@@ -1728,11 +1728,11 @@ implements Configurable
     /**
      * Initiate a server to server file transfer.  This method tells the
      * server to which the client is connected to store a file on
      * the other server using a unique filename based on the given filename.
      * The other server must have had a <code> remoteRetrieve </code> issued
      * to it by another FTPClient.
      *
-     * @param filename  The name on which to base the filename of the file
+     * @param fileName  The name on which to base the file name of the file
      *                  that is to be stored.
      * @return True if successfully completed, false if not.
      * @throws FTPConnectionClosedException
@@ -1743,11 +1743,11 @@ implements Configurable
      * @throws IOException  If an I/O error occurs while either sending a
      *      command to the server or receiving a reply from the server.
      */
-    public boolean remoteStoreUnique(String filename) throws IOException
+    public boolean remoteStoreUnique(String fileName) throws IOException
     {
         if (__dataConnectionMode == ACTIVE_REMOTE_DATA_CONNECTION_MODE ||
                 __dataConnectionMode == PASSIVE_REMOTE_DATA_CONNECTION_MODE) {
-            return FTPReply.isPositivePreliminary(stou(filename));
+            return FTPReply.isPositivePreliminary(stou(fileName));
         }
         return false;
     }
@@ -1756,10 +1756,10 @@ implements Configurable
     /**
      * Initiate a server to server file transfer.  This method tells the
      * server to which the client is connected to store a file on
      * the other server using a unique filename.
      * The other server must have had a <code> remoteRetrieve </code> issued
      * to it by another FTPClient.  Many FTP servers require that a base
      * filename be given from which the unique filename can be derived.  For
      * those servers use the other version of <code> remoteStoreUnique</code>
      *
      * @return True if successfully completed, false if not.
@@ -1787,7 +1787,7 @@ implements Configurable
      * the other server.  The other server must have had a
      * <code> remoteRetrieve </code> issued to it by another FTPClient.
      *
-     * @param filename  The name of the file to be appended to, or if the
+     * @param fileName  The name of the file to be appended to, or if the
      *        file does not exist, the name to call the file being stored.
      *
      * @return True if successfully completed, false if not.
@@ -1799,11 +1799,11 @@ implements Configurable
      * @throws IOException  If an I/O error occurs while either sending a
      *      command to the server or receiving a reply from the server.
      */
-    public boolean remoteAppend(String filename) throws IOException
+    public boolean remoteAppend(String fileName) throws IOException
     {
         if (__dataConnectionMode == ACTIVE_REMOTE_DATA_CONNECTION_MODE ||
                 __dataConnectionMode == PASSIVE_REMOTE_DATA_CONNECTION_MODE) {
-            return FTPReply.isPositivePreliminary(appe(filename));
+            return FTPReply.isPositivePreliminary(appe(fileName));
         }
         return false;
     }
@@ -2545,7 +2545,7 @@ implements Configurable
         if (success){
             String reply = getReplyStrings()[1];
             /* check the response makes sense.
              * Must have space before fact(s) and between fact(s) and filename
              * Fact(s) can be absent, so at least 3 chars are needed.
              */
             if (reply.length() < 3 || reply.charAt(0) != ' ') {
@@ -2912,13 +2912,13 @@ implements Configurable
 
 
     /**
      * Obtain a list of filenames in a directory (or just the name of a given
      * file, which is not particularly useful).  This information is obtained
      * through the NLST command.  If the given pathname is a directory and
      * contains no files,  a zero length array is returned only
      * if the FTP server returned a positive completion code, otherwise
      * null is returned (the FTP server returned a 550 error No files found.).
      * If the directory is not empty, an array of filenames in the directory is
      * returned. If the pathname corresponds
      * to a file, only that file will be listed.  The server may or may not
      * expand glob expressions.
@@ -2929,8 +2929,8 @@ implements Configurable
      *                  or prefix the path with ./ (unix style servers).
      *                  Some servers may support "--" as meaning end of options,
      *                  in which case "-- -xyz" should work.
      * @return The list of filenames contained in the given path.  null if
      *     the list could not be obtained.  If there are no filenames in
      *     the directory, a zero-length array is returned.
      * @throws FTPConnectionClosedException
      *      If the FTP server prematurely closes the connection as a result
@@ -2971,17 +2971,17 @@ implements Configurable
 
 
     /**
      * Obtain a list of filenames in the current working directory
      * This information is obtained through the NLST command.  If the current
      * directory contains no files, a zero length array is returned only
      * if the FTP server returned a positive completion code, otherwise,
      * null is returned (the FTP server returned a 550 error No files found.).
      * If the directory is not empty, an array of filenames in the directory is
      * returned.
      *
      * @return The list of filenames contained in the current working
      *     directory.  null if the list could not be obtained.
      *     If there are no filenames in the directory, a zero-length array
      *     is returned.
      * @throws FTPConnectionClosedException
      *      If the FTP server prematurely closes the connection as a result
@@ -3540,7 +3540,7 @@ implements Configurable
     /**
      * Issue the FTP STAT command to the server for a given pathname.  This
      * should produce a listing of the file or directory.
      * @param pathname the filename
      *
      * @return The status information returned by the server.
      * @throws FTPConnectionClosedException
@@ -3564,7 +3564,7 @@ implements Configurable
      * Issue the FTP SIZE command to the server for a given pathname.
      * This should produce the size of the file.
      *
      * @param pathname the filename
      *
      * @return The size information returned by the server; {@code null} if there was an error
      * @throws FTPConnectionClosedException
@@ -1701,11 +1701,11 @@ implements Configurable
      * Initiate a server to server file transfer.  This method tells the
      * server to which the client is connected to store a file on
-     * the other server using the given filename.  The other server must
+     * the other server using the given file name.  The other server must
      * have had a <code> remoteRetrieve </code> issued to it by another
      * FTPClient.
@@ -1728,11 +1728,11 @@ implements Configurable
      * Initiate a server to server file transfer.  This method tells the
      * server to which the client is connected to store a file on
-     * the other server using a unique filename based on the given filename.
+     * the other server using a unique file name based on the given file name.
      * The other server must have had a <code> remoteRetrieve </code> issued
      * to it by another FTPClient.
@@ -1756,10 +1756,10 @@ implements Configurable
      * Initiate a server to server file transfer.  This method tells the
      * server to which the client is connected to store a file on
-     * the other server using a unique filename.
+     * the other server using a unique file name.
      * The other server must have had a <code> remoteRetrieve </code> issued
      * to it by another FTPClient.  Many FTP servers require that a base
@@ -1756,10 +1756,10 @@ implements Configurable
      * The other server must have had a <code> remoteRetrieve </code> issued
      * to it by another FTPClient.  Many FTP servers require that a base
-     * filename be given from which the unique filename can be derived.  For
+     * file name be given from which the unique file name can be derived.  For
      * those servers use the other version of <code> remoteStoreUnique</code>
      *
@@ -2545,7 +2545,7 @@ implements Configurable
             String reply = getReplyStrings()[1];
             /* check the response makes sense.
-             * Must have space before fact(s) and between fact(s) and filename
+             * Must have space before fact(s) and between fact(s) and file name
              * Fact(s) can be absent, so at least 3 chars are needed.
              */
@@ -2912,13 +2912,13 @@ implements Configurable
 
     /**
-     * Obtain a list of filenames in a directory (or just the name of a given
+     * Obtain a list of file names in a directory (or just the name of a given
      * file, which is not particularly useful).  This information is obtained
      * through the NLST command.  If the given pathname is a directory and
@@ -2912,13 +2912,13 @@ implements Configurable
      * if the FTP server returned a positive completion code, otherwise
      * null is returned (the FTP server returned a 550 error No files found.).
-     * If the directory is not empty, an array of filenames in the directory is
+     * If the directory is not empty, an array of file names in the directory is
      * returned. If the pathname corresponds
      * to a file, only that file will be listed.  The server may or may not
@@ -2929,8 +2929,8 @@ implements Configurable
      *                  Some servers may support "--" as meaning end of options,
      *                  in which case "-- -xyz" should work.
-     * @return The list of filenames contained in the given path.  null if
-     *     the list could not be obtained.  If there are no filenames in
+     * @return The list of file names contained in the given path.  null if
+     *     the list could not be obtained.  If there are no file names in
      *     the directory, a zero-length array is returned.
      * @throws FTPConnectionClosedException
@@ -2971,17 +2971,17 @@ implements Configurable
 
     /**
-     * Obtain a list of filenames in the current working directory
+     * Obtain a list of file names in the current working directory
      * This information is obtained through the NLST command.  If the current
      * directory contains no files, a zero length array is returned only
@@ -2971,17 +2971,17 @@ implements Configurable
      * if the FTP server returned a positive completion code, otherwise,
      * null is returned (the FTP server returned a 550 error No files found.).
-     * If the directory is not empty, an array of filenames in the directory is
+     * If the directory is not empty, an array of file names in the directory is
      * returned.
      *
@@ -2971,17 +2971,17 @@ implements Configurable
      * returned.
      *
-     * @return The list of filenames contained in the current working
+     * @return The list of file names contained in the current working
      *     directory.  null if the list could not be obtained.
@@ -2971,17 +2971,17 @@ implements Configurable
      *     directory.  null if the list could not be obtained.
-     *     If there are no filenames in the directory, a zero-length array
+     *     If there are no file names in the directory, a zero-length array
      *     is returned.
      * @throws FTPConnectionClosedException
@@ -3540,7 +3540,7 @@ implements Configurable
      * Issue the FTP STAT command to the server for a given pathname.  This
      * should produce a listing of the file or directory.
-     * @param pathname the filename
+     * @param pathname the file name
      *
      * @return The status information returned by the server.
@@ -3564,7 +3564,7 @@ implements Configurable
      * This should produce the size of the file.
      *
-     * @param pathname the filename
+     * @param pathname the file name
      *
      * @return The size information returned by the server; {@code null} if there was an error
diff --git a/src/main/java/org/apache/commons/net/tftp/TFTPReadRequestPacket.java b/src/main/java/org/apache/commons/net/tftp/TFTPReadRequestPacket.java
index fbb84d3..f9c601d 100644
--- a/src/main/java/org/apache/commons/net/tftp/TFTPReadRequestPacket.java
+++ b/src/main/java/org/apache/commons/net/tftp/TFTPReadRequestPacket.java
@@ -47,18 +47,18 @@ public final class TFTPReadRequestPacket extends TFTPRequestPacket
 
     /***
      * Creates a read request packet to be sent to a host at a
      * given port with a filename and transfer mode request.
      *
      * @param destination  The host to which the packet is going to be sent.
      * @param port  The port to which the packet is going to be sent.
      * @param filename The requested filename.
      * @param mode The requested transfer mode.  This should be on of the TFTP
      *        class MODE constants (e.g., TFTP.NETASCII_MODE).
      ***/
     public TFTPReadRequestPacket(InetAddress destination, int port,
-                                 String filename, int mode)
+                                 String fileName, int mode)
     {
-        super(destination, port, TFTPPacket.READ_REQUEST, filename, mode);
+        super(destination, port, TFTPPacket.READ_REQUEST, fileName, mode);
     }
 
     /***
@@ -47,18 +47,18 @@ public final class TFTPReadRequestPacket extends TFTPRequestPacket
     /***
      * Creates a read request packet to be sent to a host at a
-     * given port with a filename and transfer mode request.
+     * given port with a file name and transfer mode request.
      *
      * @param destination  The host to which the packet is going to be sent.
@@ -47,18 +47,18 @@ public final class TFTPReadRequestPacket extends TFTPRequestPacket
      * @param destination  The host to which the packet is going to be sent.
      * @param port  The port to which the packet is going to be sent.
-     * @param filename The requested filename.
+     * @param fileName The requested file name.
      * @param mode The requested transfer mode.  This should be on of the TFTP
      *        class MODE constants (e.g., TFTP.NETASCII_MODE).
diff --git a/src/main/java/org/apache/commons/net/tftp/TFTPRequestPacket.java b/src/main/java/org/apache/commons/net/tftp/TFTPRequestPacket.java
index 126b5e0..ef806c1 100644
--- a/src/main/java/org/apache/commons/net/tftp/TFTPRequestPacket.java
+++ b/src/main/java/org/apache/commons/net/tftp/TFTPRequestPacket.java
@@ -69,27 +69,27 @@ public abstract class TFTPRequestPacket extends TFTPPacket
     /*** The transfer mode of the request. ***/
     private final int _mode;
 
-    /*** The filename of the request. ***/
+    /*** The file name of the request. ***/
     private final String _filename;
 
     /***
      * Creates a request packet of a given type to be sent to a host at a
      * given port with a filename and transfer mode request.
      *
      * @param destination  The host to which the packet is going to be sent.
      * @param port  The port to which the packet is going to be sent.
      * @param type The type of the request (either TFTPPacket.READ_REQUEST or
      *             TFTPPacket.WRITE_REQUEST).
      * @param filename The requested filename.
      * @param mode The requested transfer mode.  This should be on of the TFTP
      *        class MODE constants (e.g., TFTP.NETASCII_MODE).
      ***/
     TFTPRequestPacket(InetAddress destination, int port,
-                      int type, String filename, int mode)
+                      int type, String fileName, int mode)
     {
         super(type, destination, port);
 
-        _filename = filename;
+        _filename = fileName;
         _mode = mode;
     }
 
@@ -241,9 +241,9 @@ public abstract class TFTPRequestPacket extends TFTPPacket
     }
 
     /***
-     * Returns the requested filename.
+     * Returns the requested file name.
      *
-     * @return The requested filename.
+     * @return The requested file name.
      ***/
     public final String getFilename()
     {
@@ -69,27 +69,27 @@ public abstract class TFTPRequestPacket extends TFTPPacket
     /***
      * Creates a request packet of a given type to be sent to a host at a
-     * given port with a filename and transfer mode request.
+     * given port with a file name and transfer mode request.
      *
      * @param destination  The host to which the packet is going to be sent.
@@ -69,27 +69,27 @@ public abstract class TFTPRequestPacket extends TFTPPacket
      * @param type The type of the request (either TFTPPacket.READ_REQUEST or
      *             TFTPPacket.WRITE_REQUEST).
-     * @param filename The requested filename.
+     * @param fileName The requested file name.
      * @param mode The requested transfer mode.  This should be on of the TFTP
      *        class MODE constants (e.g., TFTP.NETASCII_MODE).
diff --git a/src/main/java/org/apache/commons/net/tftp/TFTPWriteRequestPacket.java b/src/main/java/org/apache/commons/net/tftp/TFTPWriteRequestPacket.java
index 7286454..5939640 100644
--- a/src/main/java/org/apache/commons/net/tftp/TFTPWriteRequestPacket.java
+++ b/src/main/java/org/apache/commons/net/tftp/TFTPWriteRequestPacket.java
@@ -47,18 +47,18 @@ public final class TFTPWriteRequestPacket extends TFTPRequestPacket
 
     /***
      * Creates a write request packet to be sent to a host at a
      * given port with a filename and transfer mode request.
      *
      * @param destination  The host to which the packet is going to be sent.
      * @param port  The port to which the packet is going to be sent.
      * @param filename The requested filename.
      * @param mode The requested transfer mode.  This should be on of the TFTP
      *        class MODE constants (e.g., TFTP.NETASCII_MODE).
      ***/
     public TFTPWriteRequestPacket(InetAddress destination, int port,
-                                  String filename, int mode)
+                                  String fileName, int mode)
     {
-        super(destination, port, TFTPPacket.WRITE_REQUEST, filename, mode);
+        super(destination, port, TFTPPacket.WRITE_REQUEST, fileName, mode);
     }
 
     /***
@@ -47,18 +47,18 @@ public final class TFTPWriteRequestPacket extends TFTPRequestPacket
     /***
      * Creates a write request packet to be sent to a host at a
-     * given port with a filename and transfer mode request.
+     * given port with a file name and transfer mode request.
      *
      * @param destination  The host to which the packet is going to be sent.
@@ -47,18 +47,18 @@ public final class TFTPWriteRequestPacket extends TFTPRequestPacket
      * @param destination  The host to which the packet is going to be sent.
      * @param port  The port to which the packet is going to be sent.
-     * @param filename The requested filename.
+     * @param fileName The requested file name.
      * @param mode The requested transfer mode.  This should be on of the TFTP
      *        class MODE constants (e.g., TFTP.NETASCII_MODE).